# == Class: nexus class puppet_nexus Full description of class nexus here.
#
# === Parameters
#
# Document parameters here.
#
# [*sample_parameter*]
#   Explanation of what this parameter affects and what it defaults to. e.g. "Specify one or more upstream ntp servers as an array."
#
# source : You need to provide the Nexus URL of the file that you are looking to download. username: provide the user name to access the Nexus 
# repository. password: provide the password to access the Nexus repository. output : give the target path where you want to store the artifacts. Here 
# you should define a list of variables that this module would require. ensure : you can provide present or absent and updated.
#
# [*sample_variable*]
#   Explanation of how this variable affects the funtion of this class and if it has a default. e.g. "The parameter enc_ntp_servers must be set by the 
#   External Node Classifier as a comma separated list of hostnames." (Note, global variables should be avoided in favor of class parameters as of 
#   Puppet 2.6.)
#
# === Examples
#
#  class nexus {# === Authors
#   url => http://edge.spree.de/nexus,# Author Name <author@domain.com> username => user,# === Copyright password => password# Copyright 2015 Your 
# name here, unless otherwise noted.
#}
#
class puppet_nexus (
  $source,
  $output,
  $ensure = update,
  $username = undef,
  $password = undef,
  $owner = undef,
  $group = undef,
  $mode = undef,
  $timeout = undef, ) {
  # Check arguments
  $nexus_url = $source
  if((!$username and $password) or ($username and !$password)) {
    fail('Cannot initialize the Nexus class - both username and password must be set')
  }
$cmd = "wget -O ${output} --user=${username} --password=${password} ${source}" if $ensure == present {
    exec { "Download ${name}":
      command => $cmd,
      path => ["/usr/bin/"],
      creates => $output,
      timeout => $timeout,
    }
  } elsif $ensure == absent {
    file { "Remove ${name}":
      ensure => absent,
      path => $output,
    }
  } else {
    exec { "Download ${name}":
      command => $cmd,
      timeout => $timeout,
      path => ["/usr/bin"],
          }
  }
  if $ensure != absent {
    file { $output:
      ensure => file,
      require => Exec["Download ${name}"],
      owner => $owner,
      group => $group,
      mode => $mode,
    }
  }
}
